@@ -105,6 +105,7 @@ class PyMOLQtGUI(QtWidgets.QMainWindow, pymol._gui.PyMOLDesktopGUI):
         self.props_panel = None
         self.builder = None
         self.shortcut_menu_filter_dialog = None
+        self.scene_panel_dialog = None
 
         # setting index -> callable
         self.setting_callbacks = defaultdict(list)
@@ -572,9 +573,9 @@ PyMOL> color ye<TAB>    (will autocomplete "yellow")
             R = form.input_R.value()
             G = form.input_G.value()
             B = form.input_B.value()
-            form.slider_R.setValue(R * 100)
-            form.slider_G.setValue(G * 100)
-            form.slider_B.setValue(B * 100)
+            form.slider_R.setValue(round(R * 100))
+            form.slider_G.setValue(round(G * 100))
+            form.slider_B.setValue(round(B * 100))
             form.frame_color.setStyleSheet(
                 "background-color: rgb(%d,%d,%d)" % (
                     R * 0xFF, G * 0xFF, B * 0xFF))
@@ -866,7 +867,7 @@ PyMOL> color ye<TAB>    (will autocomplete "yellow")
         self.cmd.cd(dname or '.', quiet=0)
 
     def confirm_quit(self):
-        QtWidgets.qApp.quit()
+        QtWidgets.QApplication.instance().quit()
 
     def settings_edit_all_dialog(self):
         from .advanced_settings_gui import PyMOLAdvancedSettings
@@ -881,6 +882,14 @@ PyMOL> color ye<TAB>    (will autocomplete "yellow")
             self.shortcut_menu_filter_dialog = PyMOLShortcutMenu(self, self.saved_shortcuts, self.cmd)
         self.shortcut_menu_filter_dialog.show()
 
+    def scene_panel_menu_dialog(self):
+        from .scene_bin_gui import ScenePanel
+
+        if self.scene_panel_dialog is None:
+            self.scene_panel_dialog = ScenePanel(self)
+
+        self.scene_panel_dialog.show()
+
     def show_about(self):
         msg = [
             'The PyMOL Molecular Graphics System\n',
