@@ -54,6 +54,7 @@ def get_command_keywords(self_cmd=cmd):
         'count_frames'  : [ self_cmd.count_frames      , 0 , 0 , ''  , parsing.STRICT ],
         'count_states'  : [ self_cmd.count_states      , 0 , 0 , ''  , parsing.STRICT ],
         'count_discrete': [ self_cmd.count_discrete    , 0 , 0 , ''  , parsing.STRICT ],
+        'curve_new'     : [ self_cmd.curve_new         , 0 , 0 , ''  , parsing.STRICT ],
         'cycle_valence' : [ self_cmd.cycle_valence     , 0 , 0 , ''  , parsing.STRICT ],
         'create'        : [ self_cmd.create            , 0 , 0 , ''  , parsing.LEGACY ],
         'decline'       : [ self_cmd.decline           , 0 , 0 , ''  , parsing.STRICT ],
@@ -82,6 +83,7 @@ def get_command_keywords(self_cmd=cmd):
         'extract'       : [ self_cmd.extract           , 0 , 0 , ''  , parsing.STRICT ],
         'exec'          : [ self_cmd.python_help       , 0 , 0 , ''  , parsing.PYTHON ],
         'fab'           : [ self_cmd.fab               , 0 , 0 , ''  , parsing.STRICT ],
+        'fnab'          : [ self_cmd.fnab              , 0 , 0 , ''  , parsing.STRICT ],
         'feedback'      : [ self_cmd.feedback          , 0,  0 , ''  , parsing.STRICT ],
         'fetch'         : [ self_cmd.fetch             , 0,  0 , ''  , parsing.STRICT ],
         'fit'           : [ self_cmd.fit               , 0 , 0 , ''  , parsing.STRICT ],
@@ -100,6 +102,7 @@ def get_command_keywords(self_cmd=cmd):
         'get_area'      : [ self_cmd.get_area          , 0 , 0 , ''  , parsing.STRICT ],
         'get_bond'      : [ self_cmd.get_bond          , 0 , 0 , ''  , parsing.STRICT ],
         'get_chains'    : [ self_cmd.get_chains        , 0 , 0 , ''  , parsing.STRICT ],
+        'get_clip'      : [ self_cmd.get_clip          , 0 , 0 , ''  , parsing.STRICT ],
         'get_dihedral'  : [ self_cmd.get_dihedral      , 0 , 0 , ''  , parsing.STRICT ],
         'get_distance'  : [ self_cmd.get_distance      , 0 , 0 , ''  , parsing.STRICT ],
         'get_extent'    : [ self_cmd.get_extent        , 0 , 0 , ''  , parsing.STRICT ],
@@ -149,6 +152,7 @@ def get_command_keywords(self_cmd=cmd):
         'log'           : [ self_cmd.log               , 0 , 0 , ''  , parsing.STRICT ],
         'log_close'     : [ self_cmd.log_close         , 0 , 0 , ''  , parsing.STRICT ],
         'log_open'      : [ self_cmd.log_open          , 0 , 0 , ''  , parsing.STRICT ],
+        'look_at'       : [ self_cmd.look_at           , 0 , 0 , ''  , parsing.STRICT ],
         'ls'            : [ self_cmd.ls                , 0 , 0 , ''  , parsing.STRICT ],
         'madd'          : [ self_cmd.madd              , 0 , 0 , ''  , parsing.STRICT ],
         'mask'          : [ self_cmd.mask              , 0 , 0 , ''  , parsing.STRICT ],
